@@ -38,6 +38,13 @@ pgls <- function(formula, data, lambda = 1.0, kappa = 1.0,  delta= 1.0,
 	k <- ncol(x)
 	namey <- names(m)[1]
 
+	# test for variables with no variance in model matrices (thx to Sarah Dryhurst)
+	# - will cause singularity - lm() filters for this and aliases variables
+	#   but here we'll just fail for the time being
+	xVar <- apply(x,2,var)[-1] # drop intercept
+	badCols <- xVar < .Machine$double.eps
+	if(any(badCols)) stop('Model matrix contains columns with zero variance: ', paste(names(xVar)[badCols], collapse=', '))
+
 	## if the comparative data doesn't contain a VCV,
 	## then get one and put it in the data object too. Bit wasteful
 	if(is.null(data$vcv)){
@@ -138,7 +145,7 @@ pgls <- function(formula, data, lambda = 1.0, kappa = 1.0,  delta= 1.0,
     
 	## run the likelihood function again with the fixed parameter values
 	## ll <- log.likelihood(optimPar=NULL, fixedPar=fixedPar, y, x, V, optim=FALSE)
-	ll <- pgls.likelihood(optimPar=NULL, fixedPar=fixedPar, y, x, V, optim=FALSE)
+	ll <- pgls.likelihood(optimPar=NULL, fixedPar=fixedPar, y, x, V, optim.output=FALSE)
 	
 	## store the log likelihood of the optimized solution for use in ci.searchs
 	log.lik <- ll$ll
@@ -542,12 +549,31 @@ fitted.pgls <- function(object, ...){
 ## CDLO - argument name changed for consistency with S3 generic
 ## CDLO - argument name of x changed to discriminate from generic to plot and print
 
-predict.pgls <- function(object, pred.x, ...) {
-    mu <- as.matrix(coef(object) )
-    ret <- cbind(1,  pred.x) %*% t(mu)
+## predict.pgls <- function(object, pred.x, ...) {
+##     mu <- as.matrix(coef(object) )
+##     ret <- cbind(1,  pred.x) %*% t(mu)
+##     return(ret)
+## }
+
+## - rewritten by CDLO to use standard method as in lm - prompted by Mike Steiper
+predict.pgls <- function (object, newdata=NULL, ...){
+	
+    # pull the data from the model if no new data is provided
+    if(is.null(newdata)){
+    	newdata <- object$data$data
+    }
+    
+    # turn that into a design matrix
+    # need to drop the response from the formula
+    dmat <- model.matrix(delete.response(terms(formula(object))), data=newdata)
+    
+    # multiply through by the coefficients
+    mu <- as.matrix(coef(object))
+    ret <- dmat %*% mu
     return(ret)
 }
 
+
 ## enables the generic AIC methods for objects and lists of objects 
 logLik.pgls <- function(object, REML = FALSE, ...){
 	
